/******************************************************************************
 *
 * Copyright (C) 2011 Harri Hyttinen
 * Copyright (C) 2011 Juuso Korhonen
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 *
 *****************************************************************************/
 
 
import QtQuick 1.1

Rectangle {
    id: banner
    property alias text: bannerText.text

    // \todo For some reason this prints out
    //       "QML InfoBanner: Cannot specify left, right, and hcenter anchors."
    //       but it still seems to work.
    anchors.horizontalCenter: parent.horizontalCenter

    width: 0
    height: 0
    radius: 7
    color: "#CC000000"
    border.width: 3
    border.color: "#767676"
    clip: true

    Text {
        id: bannerText
        anchors.centerIn: parent
        color: "white"
        width: parent.width
        font.family: "Nokia Pure Text"
        font.pointSize: 20
        wrapMode: Text.Wrap
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        text: ""
    }
    states: [
        State {
             name: "show"
             AnchorChanges {
                 target: banner
                 anchors.left: banner.parent.left
                 anchors.right: banner.parent.right
                 anchors.top: banner.parent.top
             }
             PropertyChanges {
                 target: banner
                 anchors.leftMargin: 10
                 anchors.rightMargin: 10
                 anchors.topMargin: 5
                 height: Math.max(80, bannerText.height + 6)
             }
        },
        State {
            name: "hide"
            PropertyChanges {
                target: banner
                width: 0
                height: 0
            }
        }
    ]
    transitions: [ Transition {
            to: "show"
            ParallelAnimation {
                AnchorAnimation {
                    duration: 200
                    easing.type: Easing.OutBack
                    easing.overshoot: 3
                }
                PropertyAnimation {
                    property: "height"
                    target: banner
                    duration: 200
                    easing.type: Easing.OutBack
                    easing.overshoot: 3
                }
            }
    },
        Transition {
            from: "show"
            to: "hide"
            PropertyAnimation {
                properties: "width,height"
                target: banner
                duration: 200
                easing.type: Easing.InBack
                easing.overshoot: 3
            }
        }
    ]

    MouseArea {
        anchors.fill: parent
        onClicked: {
            bannerCloseTimer.stop()
            banner.state = "hide"
        }
    }

    Timer {
        id: bannerCloseTimer
        interval: 4000
        repeat: false
        onTriggered: {
            banner.state = "hide"
        }
    }

    Component.onCompleted: { banner.state = "show"; bannerCloseTimer.start() }
}
