/******************************************************************************
 *
 * Copyright (C) 2011 Harri Hyttinen
 * Copyright (C) 2011 Juuso Korhonen
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 *
 *****************************************************************************/
 
 
import QtQuick 1.1

Component {
    Rectangle {
        id: listItem
        border.color: "#D2D2D2"
        border.width: 1
        width: songList.width;
        height: songText.height
                + songText.anchors.topMargin
                + albumArtistText.height
                + albumArtistText.anchors.bottomMargin
        gradient: listItemGradient
        property bool clicked: false

        Timer {
            id: highlightEnableTimer
            interval: 100; running: false; repeat: false
            onTriggered: {
                texts.scale = 0.95
                //gradient = clickHighlightGradient
            }
        }

        Gradient {
            id: listItemGradient
            GradientStop { position: 0.0; color: "#DCDCDC" }
            GradientStop { position: 0.6; color: "silver" }
            GradientStop { position: 1.0; color: "#DCDCDC" }
        }

        /*Gradient {
            id: clickHighlightGradient
            GradientStop { position: 0.0; color: "#ABABAB" }
            GradientStop { position: 0.6; color: "grey" }
            GradientStop { position: 1.0; color: "#ABABAB" }
        }*/

        Rectangle {
            id: texts
            anchors.fill: parent
            color: "#00000000"

            Behavior on scale {
                NumberAnimation {
                    duration: 70
                    onRunningChanged: {
                        if(listItem.clicked && !running) {
                            if(editSheet.initSheet(mimeType, file, index, title)) {
                                editSheet.open()
                            } else {
                                appWindow.showBanner("Failed to open file!", mainPage)
                            }
                            listItem.clicked = false
                            texts.scale = 1.0
                        }
                    }
                }
            }

            Text {
                id: songText
                anchors.top: parent.top
                anchors.topMargin: 5
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.right: parent.right
                anchors.rightMargin: 10
                font.pointSize: 26
                font.family: "Nokia Pure Text"
                color: "#282828"
                elide: Text.ElideRight
                text: model.title
            }

            Text {
                id: albumArtistText
                anchors.top: songText.bottom
                anchors.bottomMargin: 5
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.right: parent.right
                anchors.rightMargin: 10
                font.pointSize: 18
                font.family: "Nokia Pure Text Light"
                color: "#505050"
                elide: Text.ElideRight
                text: model.album + ((model.album.length&&model.artist.length) ? " | " : "") + model.artist
            }
        }

        MouseArea {
            id: songListDelegateMouseArea
            anchors.fill: listItem
            property int pressX: -1
            property int pressY: -1
            property int clickThreshold: 25

            onExited: {
                highlightEnableTimer.stop()
                if(!listItem.clicked) {
                    texts.scale = 1.0
                }
                //gradient = listItemGradient
            }

            onCanceled: {
                highlightEnableTimer.stop()
                texts.scale = 1.0
                //gradient = listItemGradient
            }

            onPositionChanged: {
                if(Math.abs(pressX - mouse.x) > clickThreshold ||
                   Math.abs(pressY - mouse.y) > clickThreshold) {
                    highlightEnableTimer.stop()
                    texts.scale = 1.0
                    //gradient = listItemGradient
                }
            }

            onPressed:  {
                pressX = mouse.x
                pressY = mouse.y
                highlightEnableTimer.start()
            }

            onReleased: {
                if(Math.abs(pressX - mouse.x) <= clickThreshold &&
                   Math.abs(pressY - mouse.y) <= clickThreshold) {
                    listItem.clicked = true
                }
                texts.scale = 0.95
            }
        }
    }
}
