/******************************************************************************
 *
 * Copyright (C) 2011 Harri Hyttinen
 * Copyright (C) 2011 Juuso Korhonen
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 *
 *****************************************************************************/
 
 
import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    id: root

    property bool songsModelReady: false
    signal ready ()

    property SectionScroller scroller

    FilteredSongsModel {
        id: songModel
        onModelReady: {
            songsModelReady = true
            ready()
            scroller = Qt.createQmlObject("import QtQuick 1.1; import com.nokia.meego 1.0; SectionScroller { id: scroller; listView: songList }",
                                          songs);
        }
    }

    EditSheet {
        id: editSheet
    }

    Flipable {
        id: flipable
        property bool flipped: false
        anchors.fill: parent

        front: songs
        back: SplashPage {
            disclaimerText: "<a href=\"http://license\">License</a>"
            spinnerRunning: false
            spinnerVisibility: false
            enableCloseButton: true
        }

        transform: Rotation {
            id: rotation
            origin.x: width/2
            origin.y: height/2
            axis.x: 0
            axis.y: 1
            axis.z: 0
            angle: 0
        }

        states: State {
            name: "back"
            PropertyChanges {
                target: rotation
                angle: 180
            }
            when: flipable.flipped
        }

        transitions:
            Transition {
                NumberAnimation {
                    target: rotation
                    property: "angle"
                    duration: 600
                    easing.type: Easing.InOutCubic
                }
            }

        function flip() {
            flipable.flipped = !flipable.flipped
        }

        Item {
            id: songs
            anchors.fill: parent

            ListDelegate {
                id: songListDelegate
            }

            Rectangle {
                id: searchInput
                width: parent.width
                y: parent.y - searchInput.height
                height: searchTitle.height + searchInputField.height
                color: "#DCDCDC"
                z: 1

                Behavior on y {
                    SmoothedAnimation {
                        duration: 300
                    }
                }

                Text {
                    id: searchTitle
                    anchors.left: parent.left
                    anchors.leftMargin: 10
                    text: "Search:"
                    font.family: "Nokia Pure Text Light"
                    font.pointSize: 20
                    color: "steelblue"
                }

                TextField {
                    id: searchInputField
                    anchors.right: aboutButton.left
                    anchors.rightMargin: 10
                    anchors.left: parent.left
                    anchors.leftMargin: 10
                    anchors.top: searchTitle.bottom
                    inputMethodHints: Qt.ImhNoPredictiveText

                    ToolIcon {
                        id: clearIcon
                        anchors.top: parent.top
                        anchors.right: parent.right
                        iconId: "input-clear"
                        height: parent.height
                        width: parent.height
                        onClicked: {
                            searchInputField.text = ""
                        }
                    }

                    onTextChanged: {
                        songModel.setFilterText(text)
                    }
                }

                Button {
                    id: aboutButton
                    anchors.top: searchTitle.bottom
                    anchors.right: parent.right
                    anchors.rightMargin: 10
                    width: 100
                    height: searchInputField.height
                    font.pointSize: 10
                    font.family: "Nokia Pure Text Light"
                    text: "About"
                    onClicked: {
                        flipable.flip()
                        searchInput.hide()
                    }
                }

                Timer {
                    id: hideTimer
                    interval: 5000
                    repeat: false
                    running: false
                    onTriggered: {
                        searchInput.hide()
                    }
                }
                onActiveFocusChanged: {
                    hide()
                }
                function show() {
                    if(y < 0) {
                        y = 0
                    }
                    hideTimer.restart()
                }

                function hide() {
                    if(!searchInputField.activeFocus &&
                        searchInputField.text.length === 0) {
                        if(y == 0) {
                            y = parent.y - height
                        }
                    }
                    hideTimer.stop()
                }

            }

            ListView {
                id: songList
                visible: (songModel.count > 0)
                anchors.top: searchInput.bottom
                anchors.bottom: parent.bottom
                width: parent.width
                height: parent.height - searchInput.height
                contentHeight: parent.height
                model: songModel
                delegate: songListDelegate
                flickDeceleration: 900
                maximumFlickVelocity: 2500

                flickableDirection: Flickable.VerticalFlick

                section.property: "title"
                section.criteria: ViewSection.FirstCharacter

                onFlickStarted: {
                    if(atYBeginning && visibleArea.yPosition < 0) {
                        searchInput.show()
                    } else if(visibleArea.yPosition > 0) {
                        focus = true
                        searchInput.hide()
                    }
                }
            }

            Text {
                anchors.centerIn: parent
                visible: (songModel.count === 0)
                font.pixelSize: 50
                text: "No songs found."
            }

            ScrollDecorator { flickableItem: songList }
        }
    }

    function onSave(index, title, album, artist) {
        songModel.updateRow(index, title, album ,artist)
    }

    Component.onCompleted: {
        editSheet.saved.connect(onSave)
    }

    Component.onDestruction: {
        scroller.destroy()
    }
}
