/******************************************************************************
 *
 * Copyright (C) 2011 Harri Hyttinen
 * Copyright (C) 2011 Juuso Korhonen
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 *
 *****************************************************************************/
 
 
import QtQuick 1.1
import com.nokia.meego 1.0

Item {
    id: root
    anchors.fill: parent
    property string disclaimerText: "<font size=1>N9TagEdit comes with ABSOLUTELY NO WARRANTY</font>"
    property bool disableClick: false
    property alias spinnerRunning: indicator.running
    property alias spinnerVisibility: indicator.visible
    property bool enableCloseButton: false
    signal splashCreated()
    signal splashReady()

    Timer {
        id: splashTimer
        interval: 2000
        repeat: false
        running: false
        onTriggered: {
            splashReady()
        }
    }

    BusyIndicator {
        id: indicator
        platformStyle: BusyIndicatorStyle { size: "large" }
        running:  true
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: title.top
        anchors.bottomMargin: 5
    }

    Image {
        anchors.centerIn: indicator
        id: icon
        source: "/usr/share/icons/hicolor/80x80/apps/n9tagedit80.png"
    }

    Text {
        id: title
        font.pointSize: 20
        font.family: "Nokia Pure Text Light"
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: 10
        horizontalAlignment: Text.AlignHCenter
        text: "<h2>N9TagEdit</h2>Simple audio file tag editor for N9<small><hr />version 1.0.0<br />Copyright &copy; 2011<br />Harri Hyttinen, Juuso Korhonen</small>"
    }

    Text {
        id: disclaimer
        z: 1
        font.pointSize: 20
        font.family: "Nokia Pure Text Light"
        anchors.top: title.bottom
        anchors.topMargin: 5
        anchors.horizontalCenter: parent.horizontalCenter
        horizontalAlignment: Text.AlignHCenter
        wrapMode: Text.Wrap
        text: disclaimerText

        MouseArea {
            anchors.fill: parent
            onClicked: {
                if(!disableClick) {
                    var component = Qt.createComponent("LicenseDialog.qml")
                    if(component.status == Component.Ready) {
                        component.createObject(root).open()
                    } else {
                        console.log("Failed to create License dialog!")
                    }
                }
            }
        }
    }

    Text {
        id: tagLibText
        z: 1
        font.pointSize: 15
        font.family: "Nokia Pure Text Light"
        anchors.top: disclaimer.bottom
        anchors.topMargin: 10
        anchors.horizontalCenter: parent.horizontalCenter
        horizontalAlignment: Text.AlignHCenter
        wrapMode: Text.Wrap
        text: disableClick ? "Powered by TagLib" : "<a href=\"http://http://developer.kde.org/~wheeler/taglib.html\">Powered by TagLib</a>"

        MouseArea {
            anchors.fill: parent
            onClicked: {
                if(!disableClick) {
                    Qt.openUrlExternally("http://developer.kde.org/~wheeler/taglib.html")
                }
            }
        }
    }

    MouseArea {
        anchors.fill: parent
        property int pressX: -1
        property int pressY: -1
        property int clickThreshold: 25

        onPressed:  {
            pressX = mouse.x
            pressY = mouse.y
        }

        onReleased: {
            if(!disableClick &&
               Math.abs(pressX - mouse.x) <= clickThreshold &&
               Math.abs(pressY - mouse.y) <= clickThreshold) {
                flipable.flip()
            }
        }
    }

    function startTimer() {
        splashTimer.running = true
    }
}
