/******************************************************************************
 *
 * Copyright (C) 2011 Harri Hyttinen
 * Copyright (C) 2011 Juuso Korhonen
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 *
 *****************************************************************************/
 
 
import QtQuick 1.1
import com.nokia.meego 1.0

PageStackWindow {
    id: appWindow

    initialPage: splashPage

    property MainPage mainPage

    Page {
        id: splashPage
        SplashPage { id: splash; disableClick: true }
        onStatusChanged: {
            if(status == PageStatus.Inactive) {
                splashPage.destroy()
            }
        }
    }

    Component.onCompleted: {
        splash.splashReady.connect(hideSplashPage)
        splash.startTimer()
    }

    Component.onDestruction: {
        mainPage.destroy()
    }

    function hideSplashPage() {
        var component = Qt.createComponent("MainPage.qml")
        if(component.status == Component.Ready) {
            mainPage = component.createObject(appWindow)
            if(mainPage.songsModelReady) {
                pageStack.replace(mainPage)
            } else {
                mainPage.ready.connect(songsModelReady)
            }
        } else {
            console.log("Failed to create MainPage")
            Qt.quit()
        }
    }

    function songsModelReady() {
        pageStack.replace(mainPage)
    }

    function showBanner (text, parent) {
        var component = Qt.createComponent("InfoBanner.qml")
        if(component.status == Component.Ready) {
            var infoBanner = component.createObject(parent, {"text": text});
        }
    }
}
